@@ -11,7 +11,6 @@ from .utils import form_to_schema, get_default_value
 
 FORMS = {}
 
-
 def clean_form_name(form_name):
     form_name = form_name
     form_name = re.sub(r'(?<!^)(?=[A-Z])', '-', form_name).lower()
@@ -41,7 +40,8 @@ def schema_form(request, form_class, object_id=None, method=None, content_type=N
         if form_class.endswith('-form') or form_class.endswith('Form'):
             raise ValueError('Schema forms should no longer end in "Form" or "-form"')
         if not form_class in FORMS:
-            raise Http404(f"Form with name {form_class} does not exist")
+            keys = '\n'.join(FORMS.keys())
+            raise Http404(f"Form with name {form_class} does not exist in: \n{keys}")
         form_class = FORMS[form_class]
     method = method or request.method
     content_type = content_type or request.headers.get('Content-Type', None)
@@ -54,6 +54,8 @@ def schema_form(request, form_class, object_id=None, method=None, content_type=N
     if getattr(_meta, 'login_required', None) and not request.user.is_authenticated:
         print("DEPRECATION WARNING: user form.user_can_METHOD = 'AUTH' instead of meta option.")
         return JsonResponse({'error': 'You must be logged in to do this'}, status=403)
+    if getattr(form_class, 'user_can_GET', None) == 'SELF' or getattr(form_class, 'user_can_PUT', None) == 'SELF':
+        kwargs['instance'] = request.user
 
     def check_permission(permission):
         if request.user.is_superuser:
@@ -134,6 +136,9 @@ def schema_form(request, form_class, object_id=None, method=None, content_type=N
     for field_name in form_class.Meta.fields:
         if field_name in request.GET:
             query = query.filter(**{field_name: request.GET[field_name]})
+    for field_name in getattr(form_class, 'filter_fields', None) or []:
+        if field_name in request.GET:
+            query = query.filter(**{field_name: request.GET[field_name]})
     response = JsonResponse(paginate(query, process=process, query_dict=request.GET))
     return response
 
